@@ -39,14 +39,17 @@ import relex.corpus.DocSplitter;
 import relex.corpus.DocSplitterFactory;
 import relex.entity.EntityInfo;
 import relex.entity.EntityMaintainer;
+import relex.feature.FeatureNode;
 import relex.feature.LinkView;
 import relex.frame.Frame;
 import relex.morphy.Morphy;
 import relex.morphy.MorphyFactory;
 import relex.output.OpenCogScheme;
 import relex.output.ParseView;
+import relex.output.PrologList;
 import relex.output.RawView;
 import relex.output.SimpleView;
+import relex.output.StanfordView;
 import relex.parser.LGParser;
 import relex.parser.LocalLGParser;
 import relex.parser.RemoteLGParser;
@@ -62,7 +65,7 @@ import relex.tree.PhraseTree;
  * as a stand-alone document analyzer; it supports several
  * flags modifying the displayed output.
  *
- * The primarey interface is the processSentence() method,
+ * The primary interface is the processSentence() method,
  * which accepts one sentence at a time, parses it, and extracts
  * relationships from it. This method is stateful: it also
  * performs anaphora resolution.
@@ -75,7 +78,6 @@ public class RelationExtractor
 	public static final int DEFAULT_MAX_SENTENCE_LENGTH = 1024;
 	public static final int DEFAULT_MAX_PARSE_SECONDS = 30;
 	public static final int DEFAULT_MAX_PARSE_COST = 1000;
-	public static final String DEFAULT_ALGS_FILE = "./data/relex-semantic-algs.txt";
 
 	/** The LinkParserClient to be used - this class isn't thread safe! */
 	private RelexContext context;
@@ -98,6 +100,9 @@ public class RelationExtractor
 	/** Document - holder of sentences */
 	Document doco;
 
+	/* Stanford parser compatibility mode */
+	public boolean do_stanford;
+
 	/** Statistics */
 	private ParseStats stats;
 
@@ -133,6 +138,8 @@ public class RelationExtractor
 
 		doco = new Document();
 
+		do_stanford = false;
+
 		stats = new ParseStats();
 		sumtime = new TreeMap<String,Long>();
 		cnttime = new TreeMap<String,Long>(); 
@@ -213,6 +220,7 @@ public class RelationExtractor
 
 				// The actual relation extraction is done here.
 				sentenceAlgorithmApplier.applyAlgs(parse, context);
+				if (do_stanford) sentenceAlgorithmApplier.extractStanford(parse, context);
 
 				// Strip out the entity markup, so that when the
 				// sentence is printed, we don't print gunk.
@@ -344,18 +352,20 @@ public class RelationExtractor
 			" [-h (show this help)]" +
 			" [-l (show parse links)]" +
 			" [-m (show parse metadata)]" +
+			" [--maxParseSeconds N]" +
 			" [-n max number of parses to display]" +
 			" [-o (show opencog scheme output)]" +
 			" [--pa (show phrase-based lexical chunks)]" +
 			" [--pb (show pattern-based lexical chunks)]" +
 			" [--pc (show relational lexical chunks)]" +
+			" [--prolog (show prolog output)]" +
 			" [-q (do NOT show relations)]" +
 			" [-r (show raw output)]" +
 			" [-s Sentence (in quotes)]" +
+			" [--stanford (generate stanford-compatible output)]" +
 			" [-t (show parse tree)]" +
-			" [-v verbose]" +
-			" [-x (show cerego XML output)]" +
-			" [--maxParseSeconds N]";
+			" [-v (verbose, full graph output)]" +
+			" [-x (show cerego XML output)]";
 		HashSet<String> flags = new HashSet<String>();
 		flags.add("-a");
 		flags.add("-c");
@@ -368,8 +378,10 @@ public class RelationExtractor
 		flags.add("--pa");
 		flags.add("--pb");
 		flags.add("--pc");
+		flags.add("--prolog");
 		flags.add("-q");
 		flags.add("-r");
+		flags.add("--stanford");
 		flags.add("-t");
 		flags.add("-v");
 		flags.add("-x");
@@ -427,6 +439,11 @@ public class RelationExtractor
 			re.do_anaphora_resolution = true;
 		}
 
+		if (commandMap.get("--stanford") != null)
+		{
+			re.do_stanford = true;
+		}
+
 		EntityMaintainerFactory gem = null;
 		if (commandMap.get("-g") != null)
 		{
@@ -617,6 +634,22 @@ public class RelationExtractor
 						ranker.add(chunker.getChunks(), parse.getTruthValue(), votes);
 					}
 
+					if (commandMap.get("--prolog") != null)
+					{
+						PrologList pl = new PrologList();
+						System.out.println(
+							pl.toPrologList(parse.getLeft(), 
+								PrologList.getDefaultFilter(),
+								true));
+						System.out.println("\n======\n");
+					}
+
+					if (commandMap.get("--stanford") != null)
+					{
+						System.out.println(StanfordView.printRelations(parse));
+						System.out.println("\n======\n");
+					}
+
 					if (commandMap.get("-c") != null)
 					{
 						ceregoView.setParse(parse);
