@@ -28,6 +28,7 @@ import relex.feature.FeatureNode;
 
 public abstract class SentenceAlgorithm
 {
+	private static final boolean DEBUG = false;
 	private static String SIGNATURE_FEATURE_NAME = "SIG";
 
 	public static boolean VERBOSE = false;
@@ -47,7 +48,7 @@ public abstract class SentenceAlgorithm
 			if (null != vars) {
 				boolean printResult = false;
 				if (VERBOSE)
-					System.out.print(" " + getSignature());
+					System.err.print(" " + getSignature());
 				if (INTERACTIVE) {
 					BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
 					try {
@@ -60,13 +61,17 @@ public abstract class SentenceAlgorithm
 				try {
 					applyTo(c, context, vars);
 				} catch (Exception e) {
+					if (DEBUG)
+					{
+						// System.err.println(sentence);
+						// System.err.println(this);
+						System.err.println("Error: bad algorithm: " + getSignature());
+						e.printStackTrace();
+					}
 					sentence.setErrorString(this + "\n" + e.toString());
-					// System.out.println(sentence);
-					// System.out.println(this);
-					// e.printStackTrace();
 				}
 				if (printResult)
-					System.out.println(sentence);
+					System.err.println("Info: " + sentence);
 				
 				FeatureNode f = c.get(SIGNATURE_FEATURE_NAME);
 				if (f == null) {
