@@ -18,6 +18,10 @@ import java.util.List;
 
 public class DocSplitterFallbackImpl implements DocSplitter
 {
+	public boolean operational()
+	{
+		return true;
+	}
 	public boolean acceptableBreak(String s, int start, int end)
 	{
 		return false;
@@ -37,19 +41,31 @@ public class DocSplitterFallbackImpl implements DocSplitter
 
 	public String getNextSentence()
 	{
-		String s = sb.toString();
-		clearBuffer();
+		String s = "";
+		int nl = sb.indexOf("\n");
+		if (0 < nl)
+		{
+			s = sb.substring(0,nl);
+			sb = sb.delete(0,nl);
+		}
+		else
+		{
+			s = sb.toString();
+			clearBuffer();
+		}
 		if (s.equals("")) s = null;
 		return s;
 	}
 
 	public List<TextInterval> process(String docText)
 	{
+		// XXX this is wrong, it fails to look for newlines!
 		return Arrays.asList(new TextInterval(0,docText.length()-1));
 	}
 
 	public List<String> split(String docText)
 	{
+		// XXX this is wrong, it fails to look for newlines!
 		return Arrays.asList(docText);
 	}
 }
