@@ -22,6 +22,8 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Set;
 
+import relex.output.PrologList;
+
 /**
  * FeatureNodes may store either a set of key-value pairs, where the
  * values are other FeatureNodes, or they may store a single string.
@@ -240,71 +242,103 @@ public class FeatureNode extends Atom
 	 * If "this" isEmpty, then it is replaced with other, which means that after
 	 * calling this method, "this" is not guaranteed to be a legitimate part of
 	 * the entire feature structure you were dealing with.
+	 *
+	 * XXX -- this is somewhat strangely named, it doesn't really
+	 * merge, per-se, since if both featurenodes have features
+	 * in them, then it throws an exeption if the features aren't 
+	 * identical. So really, a "merge" occurs only when one of the
+	 * featurenodes is empty.
+	 *
+	 * What's even crazier, the SentenceAlgorithm.java silently
+	 * eats the exceptions thrown here. So its all pretty pointless...
+	 *
+	 * So basically, this is just kind of crazy, I think.  This
+	 * makes sense only if the algs files are cleanly built...
+	 *
+	 * Returns the merged node.
 	 */
-	public void mergeWith(FeatureNode other)
+	public FeatureNode mergeWith(FeatureNode other)
 	{
 		if (other == this)
-			return;
+			return this;
 		if (other.isEmpty()) {
 			other.replaceSelfWith(this);
-			return;
+			return other;
 		}
 		if (isEmpty()) {
 			replaceSelfWith(other);
-			return;
+			return this;
 		}
 
 		// Throw execeptions if the two FeatureNodes are non-unifiable
-		if (!isEmpty() && !other.isEmpty()) {
-			if (isValued()) {
-				if ((!other.isValued())
-						|| (!other.getValue().equals(getValue()))) {
-					throw new RuntimeException(
-							"Cannot merge a nonvalued node or a node with a different value into a non-empty valued node");
-				}
-			} else { // this has features
-				if (other.isValued()) { // other has value
-					throw new RuntimeException(
-							"Cannot merge a non-empty valued node into a non-empty normal feature node");
-				}
-				// other has features
-				Iterator<String> i = other.getFeatureNames().iterator();
-				while (i.hasNext()) {
-					String fName = i.next();
-					FeatureNode f = other.get(fName);
-					if (f != get(fName))
-						throw new RuntimeException(
-								"Cannot merge two non-valued feature nodes with inconsistent features.");
-				}
+		if (isValued())
+		{
+			if ((!other.isValued())
+					|| (!other.getValue().equals(getValue())))
+			{
+				throw new RuntimeException(
+						"Cannot merge a nonvalued node or a node with a different value into a non-empty valued node");
+			}
+		}
+		else
+		{ // this has features
+			if (other.isValued())
+			{ // other has value
+				throw new RuntimeException(
+						"Cannot merge a non-empty valued node into a non-empty normal feature node");
+			}
 
+			// other has features
+			for (String fName : other.getFeatureNames())
+			{
+				FeatureNode otherf = other.get(fName);
+				FeatureNode thisf = this.get(fName);
+
+				if (otherf != thisf)
+				{
+					throw new RuntimeException(
+						"Cannot merge two non-valued feature nodes with inconsistent features.\n" +
+						"\tSuggest using += instead of = in algs file. fName = " + fName);
+				}
 			}
 		}
 
-		// after checking for inconsistencies above, we can safely execute the
+		return this;
+	}
+
+	public FeatureNode copyInto(FeatureNode other)
+	{
+		if (other == this)
+			return this;
+
+		// Throw execeptions if the two FeatureNodes are non-unifiable
+		if (isValued())
+		{
+			if (!other.isValued())
+			{
+				throw new RuntimeException(
+						"Cannot merge a nonvalued node into a non-empty valued node");
+			}
+		}
+		else
+		{ // this has features
+			if (other.isValued())
+			{ // other has value
+				throw new RuntimeException(
+						"Cannot merge a non-empty valued node into a non-empty normal feature node");
+			}
+		}
+
+		// After checking for inconsistencies above, we can safely execute the
 		// code below
-		if (!isEmpty()) {
-			if ((!isValued()) && (!other.isValued())) {
-				Iterator<String> i = other.getFeatureNames().iterator();
-				while (i.hasNext()) {
-					String fName = i.next();
-					set(fName, other.get(fName));
-				}
-			}
-		} else { // empty
-			if (other.isValued()) {
-				forceValue(other.getValue());
-			} else {
-				// copy all of other's features to this
-				forceFeatures();
-				Iterator<String> i = other.getFeatureNames().iterator();
-				while (i.hasNext()) {
-					String fName = i.next();
-					set(fName, other.get(fName));
-				}
+		if (!isValued())
+		{
+			for (String fName : other.getFeatureNames())
+			{
+				set(fName, other.get(fName));
 			}
 		}
-		other.replaceSelfWith(this);
-
+		return this;
 	}
 
 	public void replaceSelfWith(FeatureNode other)
@@ -312,7 +346,7 @@ public class FeatureNode extends Atom
 		if (other == this)
 			return;
 		// Create a new hashset to avoid ConcurrentModificationException.
-		// That is, we will be modifyinh parents as we iterate through its
+		// That is, we will be modifying parents as we iterate through its
 		// *copy*.
 		Iterator<FeatureNode> i = new HashSet<FeatureNode>(parents).iterator();
 		while (i.hasNext()) {
