@@ -28,29 +28,29 @@ import relex.feature.LinkableView;
 
 public class RemoteLGParser extends LGParser
 {
-    private LGRemoteClient linkGrammarClient = new LGRemoteClient();
-	
+	private LGRemoteClient linkGrammarClient = new LGRemoteClient();
+
 	private Sentence parseResultToSentence(ParseResult parseResult)
 	{
-		Sentence sntc = new Sentence();		
+		Sentence sntc = new Sentence();
 		sntc.setSentence(parseResult.getText());
-		
-		if (parseResult.getLinkages().isEmpty() || 
+
+		if (parseResult.getLinkages().isEmpty() ||
 			!config.isAllowSkippedWords() && parseResult.getNumSkippedWords() > 0)
 			return sntc;
-		
+
 		String lowerCaseText = parseResult.getText().toLowerCase();
-		
+
 		for (Linkage linkage : parseResult)
 		{
 			ParsedSentence parsedSentence = new ParsedSentence(parseResult.getText());
 			parsedSentence.setSentence(sntc);
 			sntc.getParses().add(parsedSentence);
-			
+
 			boolean ignoreLast = false;
 			FeatureNode lastFN = null;
 			FeatureNode leftWall = null;
-			
+
 			int startChar = 0;
 			HashMap<String,Integer> timesTokenSeen = new HashMap<String,Integer>();
 			for (int w = 0; w < linkage.getLinkedWordCount(); w++)
@@ -65,18 +65,18 @@ public class RemoteLGParser extends LGParser
 				{
 					LinkableView fnv = new LinkableView(new FeatureNode());
 					if (wordString.equals("LEFT-WALL")) leftWall = fnv.fn();
-					// LEFT-WALL should always be first word, so throw an 
+					// LEFT-WALL should always be first word, so throw an
 					// exception if it was not.
 					if (leftWall == null)
 						throw new RuntimeException("Invalid parse: " +
 							"first word is not left wall");
-					
+
 					// set the word and part-of-speach
 					fnv.setWordAndPos(wordString);
-					
+
 					// create a feature "this" which points to the linkable
 					fnv.fn().set("this", fnv.fn());
-					
+
 					// set "wall" to point to the left wall
 					fnv.fn().set("wall", leftWall);
 					if (lastFN != null)
@@ -84,12 +84,12 @@ public class RemoteLGParser extends LGParser
 						LinkableView.setNext(lastFN, fnv.fn());
 						fnv.setPrev(lastFN);
 					}
-					
+
 					if (parseResult.getEntityFlags()[w] || Character.isUpperCase(wordString.charAt(0)))
 						fnv.setEntityFlag();
 					if (parseResult.getPastTenseFlags()[w])
 						fnv.setTenseVal("past");
-					
+
 					parsedSentence.addWord(fnv.fn());
 
 					//
@@ -99,10 +99,10 @@ public class RemoteLGParser extends LGParser
 					// off this class. The loop is over all words in the current linkage, but
 					// the token is obtained from a global array of all tokens in the sentence
 					// (regardless of whether they participate in the current parse or are skipped).
-					// And anyway, in case of skipped words, how are you going to get the 
+					// And anyway, in case of skipped words, how are you going to get the
 					// character index right? Need to know which words exactly have been skipped.
 					String tokenString = parseResult.wordAt(w).toLowerCase(); // normalize cases
-					
+
 					Integer timesSeenInt = timesTokenSeen.get(tokenString);
 					int timesSeen = (timesSeenInt == null ? 0 : timesSeenInt.intValue());
 
@@ -124,21 +124,21 @@ public class RemoteLGParser extends LGParser
 					lastFN = fnv.fn();
 				}
 			}
-			
+
 			for (Link link : linkage)
 				if (!ignoreLast || link.getRight() != linkage.getLinkedWordCount() - 1)
 				{
 					new LinkView(new FeatureNode()).setLinkFeatures(
-							link.getLeftLabel(), 
-							link.getRightLabel(), 
-							link.getLabel(), 
-							parsedSentence.getWordAsNode(link.getLeft()), 
+							link.getLeftLabel(),
+							link.getRightLabel(),
+							link.getLabel(),
+							parsedSentence.getWordAsNode(link.getLeft()),
 							parsedSentence.getWordAsNode(link.getRight())
 					);
 				}
-			
+
 			parsedSentence.setPhraseString(linkage.getConstituentString());
-			
+
 			// set meta data
 			FeatureNode meta = new FeatureNode();
 			meta.set("num_skipped_words", new FeatureNode(Integer.toString(parseResult.getNumSkippedWords())));
@@ -146,47 +146,49 @@ public class RemoteLGParser extends LGParser
 			meta.set("disjunct_cost", new FeatureNode(Integer.toString(linkage.getDisjunctCost())));
 			meta.set("link_cost", new FeatureNode(Integer.toString(linkage.getLinkCost())));
 			meta.set("num_violations", new FeatureNode(Integer.toString(linkage.getNumViolations())));
-			parsedSentence.setMetaData(meta);			
+			parsedSentence.setMetaData(meta);
 		}
-		return sntc;		
+		return sntc;
 	}
-	
+
 	// @Override
 	public Sentence parse(String sentence)
 	{
-	    try
-	    {
-	        ParseResult parseResult = linkGrammarClient.parse(sentence);
+		try
+		{
+			ParseResult parseResult = linkGrammarClient.parse(sentence);
+			if (parseResult == null)
+				return null;
 			parseResult.setText(sentence);
 			return parseResultToSentence(parseResult);
-		} 
+		}
 		catch (InterruptedException ex)
 		{
 			throw new ParseException("Thread interrupted.", ex);
 		}
 		catch (Throwable t)
 		{
-		    throw new ParseException(sentence, t);
+			throw new ParseException(sentence, t);
 		}
 	}
-		
-    @Override
-    public String getVersion()
-    {
-        return getLinkGrammarClient().getVersion();
-    }
-    
+
+	@Override
+	public String getVersion()
+	{
+		return getLinkGrammarClient().getVersion();
+	}
+
 	public LGRemoteClient getLinkGrammarClient()
-    {
-        return linkGrammarClient;
-    }
+	{
+	return linkGrammarClient;
+	}
 
-    public void setLinkGrammarClient(LGRemoteClient linkGrammarClient)
-    {
-        this.linkGrammarClient = linkGrammarClient;
-    }
+	public void setLinkGrammarClient(LGRemoteClient linkGrammarClient)
+	{
+		this.linkGrammarClient = linkGrammarClient;
+	}
 
-    public static void main(String[] args)
+	public static void main(String[] args)
 	{
 		if (args.length != 2)
 		{
@@ -200,5 +202,5 @@ public class RemoteLGParser extends LGParser
 		parser.getLinkGrammarClient().getConfig().setAllowSkippedWords(true);
 		parser.getLinkGrammarClient().getConfig().setMaxLinkages(5);
 		parser.parse(args[1]);
-	}	
+	}
 }
